# yg — "YAML grep"

Searches in YAML files for properties that matches a regex and prints them.

`usage: yg pattern [files]`

> For more intricate command line YAML manipulation, check out [yq](https://github.com/mikefarah/yq).

## Installation

`$ pip install folkol.yg`

## Examples

- finds Ansible variables matching nginx: yg nginx

